__version__ = '1.0.0'


import os
from os.path import expanduser
import warnings


def get_default_root():
    home = expanduser('~')
    dirpath = os.path.join(home, '.robust-minisets')

    try:
        if not os.path.exists(dirpath):
            os.makedirs(dirpath)
    except:
        warnings.warn('Failed to setup default root.')
        dirpath = None

    return dirpath

DEFAULT_ROOT = get_default_root()

HOMEPAGE = 'https://github.com/CeMOS-IS/Robust-Minisets'

INFO = {
    'cifar-10-1': {
        'python_class': 'CIFAR10_1',
        'description': 'CIFAR-10.1 (v4) is a new test set for the CIFAR-10 dataset introduced by Recht et al. ("Do CIFAR-10 Classifiers Generalize to CIFAR-10?") with 2,000 images spanning all 10 classes of the original CIFAR-10 dataset. CIFAR-10.1 consists of images sampled from the TinyImages dataset based on keyword search and count. For further information visit the original GitHub repository of CIFAR-10.1: https://github.com/modestyachts/CIFAR-10.1.',
        'url': 'https://zenodo.org/records/13382927/files/cifar-10-1.npz?download=1',
        'MD5' : '94f23efd6fcb77bdd1603a856e188cc4',
        'n_channels': 3,
        'n_classes': 10,
        'resolution': "32×32",
        'n_samples': {'test': 2021},
        'license': 'MIT License'
    },
    'cifar-10-c': {
        'python_class': 'CIFAR10C',
        'description': 'CIFAR-10-C is an open-source data set comprising algorithmically generated corruptions applied to the CIFAR-10 test set comprising 10 classes following the concept of ImageNet-C. It was introduced by Hendrycks et al. ("Benchmarking Neural Network Robustness to Common Corruptions and Perturbations") and comprises 19 different corruptions (15 test corruptions and 4 validation corruptions) spanning 5 severity levels. This results in 200,000 images for the validation set and 750,000 images for the test set. For further information visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/cifar-10-c.npz?download=1',
        'MD5' : '4ca974be59221c789dc635253ce4fc43',
        'n_channels': 3,
        'n_classes': 10,
        'resolution': "32×32",
        'n_samples': {'val': 200000, 'test': 750000},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'snow', 'frost', 'fog', 
                                        'brightness', 'contrast', 'elastic_transform', 'pixelate',
                                        'jpeg_compression']},
        'license': 'CC BY 4.0'
    },
    'cifar-100-c': {
        'python_class': 'CIFAR100C',
        'description': 'CIFAR-100-C is an open-source data set comprising algorithmically generated corruptions applied to the CIFAR-100 test set comprising 100 classes following the concept of ImageNet-C. It was introduced by Hendrycks et al. ("Benchmarking Neural Network Robustness to Common Corruptions and Perturbations") and comprises 19 different corruptions (15 test corruptions and 4 validation corruptions) spanning 5 severity levels. This results in 200,000 images for the validation set and 750,000 images for the test set. For further information visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/cifar-100-c.npz?download=1',
        'MD5' : '6a514eae094e522d7586a908e2db672f',
        'n_channels': 3,
        'n_classes': 100,
        'resolution': "32×32",
        'n_samples': {'val': 200000, 'test': 750000},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'snow', 'frost', 'fog', 
                                        'brightness', 'contrast', 'elastic_transform', 'pixelate',
                                        'jpeg_compression']},
        'license': 'CC BY 4.0'
    },
    'eurosat': {
        'python_class': 'EuroSAT',
        'description': 'EuroSAT is a dataset and deep learning benchmark for land use and land cover classification. The dataset is based on Sentinel-2 satellite images consisting of 10 classes with in total 27,000 labeled samples. For the train/val/test split we follow Neumann et al. ("In-Domain Representation Learning for Remote Sensing", Google Research). For further information visit the original GitHub repository of EuroSAT: https://github.com/phelber/EuroSAT.',
        'url': 'https://zenodo.org/records/13382927/files/eurosat.npz?download=1',
        'MD5' : 'e1ef60d35e2131e83e90bd6369cd4305',
        'n_channels': 3,
        'n_classes': 10,
        'resolution': "64×64",
        'n_samples': {'train': 16200, 'val': 5400, 'test': 5400},
        'license': 'MIT License',
    },
    'eurosat-c': {
        'python_class': 'EuroSATC',
        'description': 'EuroSAT-C is an open-source data set comprising algorithmically generated corruptions applied to the EuroSAT test set following the concept of ImageNet-C. It comprises 19 different corruptions (15 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 108,000 images for the validation set and 405,000 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/eurosat-c.npz?download=1',
        'MD5' : 'db6eb7ba44c4e712a06d1aa5efdd344e',
        'n_channels': 3,
        'n_classes': 10,
        'resolution': "64×64",
        'n_samples': {'val': 108000, 'test': 405000},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'snow', 'frost', 'fog', 
                                        'brightness', 'contrast', 'elastic_transform', 'pixelate',
                                        'jpeg_compression']},
        'license': 'MIT License',
    },
    'bloodmnist-c': {
        'python_class': 'BloodMNISTC',
        'description': 'BloodMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the BloodMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 68,420 images for the validation set and 205,260 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/bloodmnist-c.npz?download=1',
        'MD5' : '3a3c0504c029fa27d3b5f1e074213d1c',
        'n_channels': 3,
        'n_classes': 8,
        'resolution': "28×28",
        'n_samples': {'val': 68420, 'test': 205260},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'breastmnist-c': {
        'python_class': 'BreastMNISTC',
        'description': 'BreastMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the BreastMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 3,120 images for the validation set and 9,360 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/breastmnist-c.npz?download=1',
        'MD5' : '2f2436199e3de2d573cd0234caeb3702',
        'n_channels': 3,
        'n_classes': 2,
        'resolution': "28×28",
        'n_samples': {'val': 3120, 'test': 9360},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'dermamnist-c': {
        'python_class': 'DermaMNISTC',
        'description': 'DermaMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the DermaMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 40,100 images for the validation set and 120,300 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/dermamnist-c.npz?download=1',
        'MD5' : '040ab28371f4a31732cec7c821b3d8dc',
        'n_channels': 3,
        'n_classes': 7,
        'resolution': "28×28",
        'n_samples': {'val': 40100, 'test': 120300},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY-NC 4.0',
    },
    'octmnist-c': {
        'python_class': 'OCTMNISTC',
        'description': 'OCTMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the OCTMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 20,000 images for the validation set and 60,000 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/octmnist-c.npz?download=1',
        'MD5' : '32fa28c75ba96e11f2e19086999db6ff',
        'n_channels': 3,
        'n_classes': 4,
        'resolution': "28×28",
        'n_samples': {'val': 20000, 'test': 60000},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'organamnist-c': {
        'python_class': 'OrganAMNISTC',
        'description': 'OrganAMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the OrganAMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 355,560 images for the validation set and 1,066,680 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/organamnist-c.npz?download=1',
        'MD5' : 'bd721d8fb91de7dd61df9b6bc007e3d7',
        'n_channels': 3,
        'n_classes': 11,
        'resolution': "28×28",
        'n_samples': {'val': 355560, 'test': 1066680},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'organcmnist-c': {
        'python_class': 'OrganCMNISTC',
        'description': 'OrganCMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the OrganCMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 164,320 images for the validation set and 492,960 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/organcmnist-c.npz?download=1',
        'MD5' : 'ef4888517e2fdb8d58cc6e8b428e0d3c',
        'n_channels': 3,
        'n_classes': 11,
        'resolution': "28×28",
        'n_samples': {'val': 164320, 'test': 492960},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'organsmnist-c': {
        'python_class': 'OrganSMNISTC',
        'description': 'OrganSMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the OrganSMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 176,540 images for the validation set and 529,620 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/organsmnist-c.npz?download=1',
        'MD5' : 'f7ff9e6313839b041ac2366b384a9750',
        'n_channels': 3,
        'n_classes': 11,
        'resolution': "28×28",
        'n_samples': {'val': 176540, 'test': 529620},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'pathmnist-c': {
        'python_class': 'PathMNISTC',
        'description': 'PathMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the PathMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 143,600 images for the validation set and 430,800 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/pathmnist-c.npz?download=1',
        'MD5' : '4897e35062c829c7b7d7ccb20980a9a8',
        'n_channels': 3,
        'n_classes': 9,
        'resolution': "28×28",
        'n_samples': {'val': 143600,'test': 430800},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'pneumoniamnist-c': {
        'python_class': 'PneumoniaMNISTC',
        'description': 'PneumoniaMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the PneumoniaMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 12,480 images for the validation set and 37,440 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/pneumoniamnist-c.npz?download=1',
        'MD5' : '600203dd39d7067e873feb0d0bc5665a',
        'n_channels': 3,
        'n_classes': 2,
        'resolution': "28×28",
        'n_samples': {'val': 12480, 'test': 37440},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'tissuemnist-c': {
        'python_class': 'TissueMNISTC',
        'description': 'TissueMNIST-C is an open-source data set comprising algorithmically generated corruptions applied to the TissueMNIST test set of the MedMNIST collection (https://medmnist.com) following the concept of ImageNet-C. It comprises 16 different corruptions (12 test corruptions and 4 validation corruptions) spanning 5 severity levels resulting in 945,600 images for the validation set and 2,836,800 images for the test set. For further information on the corruptions visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/tissuemnist-c.npz?download=1',
        'MD5' : 'a98e3ed7375e58a6b792f832007ba4fd',
        'n_channels': 3,
        'n_classes': 8,
        'resolution': "28×28",
        'n_samples': {'val': 945600, 'test': 2836800},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'brightness', 'contrast',
                                        'elastic_transform', 'pixelate', 'jpeg_compression']},
        'license': 'CC BY 4.0',
    },
    'tiny-imagenet': {
        'python_class': 'TinyImageNet',
        'description': 'Tiny Imagenet is a scaled down version of the ImageNet dataset and was created by folks at the Stanford University. Tiny ImageNet contains 100,000 images of 200 classes (500 for each class) downsized to 64×64 colored images. Each class has 500 training images and 50 test images.',
        'url': 'https://zenodo.org/records/13382927/files/tiny-imagenet.npz?download=1',
        'MD5' : '4244dd6c3f455ef896f53dc7d6845063',
        'n_channels': 3,
        'n_classes': 200,
        'resolution': "64×64",
        'n_samples': {'train': 100000, 'test': 10000},
        'license': ''
    },
    'tiny-imagenet-a': {
        'python_class': 'TinyImageNetA',
        'description': 'Tiny ImageNet-A is a subset of the Tiny ImageNet test set consisting of 3,374 images comprising real-world, unmodified, and naturally occurring examples that are misclassified by ResNet-18. The sampling process of Tiny ImageNet-A roughly follows the concept of ImageNet-A introduced by Hendrycks et al. ("Natural Adversarial Examples"). For further information visit the original GitHub repository of ImageNet-A: https://github.com/hendrycks/natural-adv-examples.',
        'url': 'https://zenodo.org/records/13382927/files/tiny-imagenet-a.npz?download=1',
        'MD5' : '2af2444006b3088e83a73c99c08dcdc1',
        'n_channels': 3,
        'n_classes': 200,
        'resolution': "64×64",
        'n_samples': {'test': 3374},
        'license': ''
    },
    'tiny-imagenet-c': {
        'python_class': 'TinyImageNetC',
        'description': 'Tiny ImageNet-C is an open-source data set comprising algorithmically generated corruptions applied to the Tiny ImageNet test set comprising 200 classes following the concept of ImageNet-C. It was introduced by Hendrycks et al. ("Benchmarking Neural Network Robustness to Common Corruptions and Perturbations") and comprises 19 different corruptions (15 test corruptions and 4 validation corruptions) spanning 5 severity levels. This results in 200,000 images for the validation set and 750,000 images for the test set. For further information visit the original GitHub repository of ImageNet-C: https://github.com/hendrycks/robustness.',
        'url': 'https://zenodo.org/records/13382927/files/tiny-imagenet-c.npz?download=1',
        'MD5' : '00c826e4c2aaf94f92060aedc4cba9b8',
        'n_channels': 3,
        'n_classes': 200,
        'resolution': "64×64",
        'n_samples': {'val': 200000,'test': 750000},
        'corruption_dict': {'val'    : ['speckle_noise', 'gaussian_blur', 'spatter', 'saturate'],
                            'test'   : ['gaussian_noise', 'shot_noise', 'impulse_noise', 'defocus_blur',
                                        'glass_blur', 'motion_blur', 'zoom_blur', 'snow', 'frost', 'fog', 
                                        'brightness', 'contrast', 'elastic_transform', 'pixelate',
                                        'jpeg_compression']},
        'license': 'CC BY 4.0'
    },
    'tiny-imagenet-r': {
        'python_class': 'TinyImageNetR',
        'description': 'Tiny ImageNet-R is a subset of the ImageNet-R dataset by Hendrycks et al. ("The Many Faces of Robustness: A Critical Analysis of Out-of-Distribution Generalization") with 10,456 images spanning 62 of the 200 Tiny ImageNet dataset. It is a test set achieved by collecting images of joint classes of Tiny ImageNet and ImageNet. The resized images of size 64×64 contain art, cartoons, deviantart, graffiti, embroidery, graphics, origami, paintings, patterns, plastic objects, plush objects, sculptures, sketches, tattoos, toys, and video game renditions of ImageNet classes. For further information visit the original GitHub repository of ImageNet-R: https://github.com/hendrycks/imagenet-r.',
        'url': 'https://zenodo.org/records/13382927/files/tiny-imagenet-r.npz?download=1',
        'MD5' : '1eb15640b4f5cbb3c6ba3f0e19b61f4a',
        'n_channels': 3,
        'n_classes': 200,
        'resolution': "64×64",
        'n_samples': {'test': 10456},
        'license': 'MIT License'
    },
    'tiny-imagenet-v2': {
        'python_class': 'TinyImageNetv2',
        'description': 'Tiny ImageNetv2 is a subset of the ImageNetV2 (matched frequency) dataset by Recht et al. ("Do ImageNet Classifiers Generalize to ImageNet?") with 2,000 images spanning all 200 classes of the Tiny ImageNet dataset. It is a test set achieved by collecting images of joint classes of Tiny ImageNet and ImageNet. The resized images of size 64×64 consist of images collected from Flickr after a decade of progress on the original ImageNet dataset. The data collection process was designed to resemble the original ImageNet dataset distribution. For further information visit the original GitHub repository of ImageNetV2: https://github.com/modestyachts/ImageNetV2.',
        'url': 'https://zenodo.org/records/13382927/files/tiny-imagenet-v2.npz?download=1',
        'MD5' : 'f66c5951ef5b1796bdb7f34d4e01a3ec',
        'n_channels': 3,
        'n_classes': 200,
        'resolution': "64×64",
        'n_samples': {'test': 2000},
        'license': 'MIT License'
    }
}
